# autobean-refactor
[![build](https://github.com/SEIAROTg/autobean-refactor/actions/workflows/build.yml/badge.svg)](https://github.com/SEIAROTg/autobean-refactor/actions/workflows/build.yml)
[![pypi](https://img.shields.io/pypi/v/autobean-refactor)](https://pypi.org/project/autobean-refactor/)
[![Test Coverage](https://api.codeclimate.com/v1/badges/8acbf50474596bc201ab/test_coverage)](https://codeclimate.com/github/SEIAROTg/autobean-refactor/test_coverage)
[![Maintainability](https://api.codeclimate.com/v1/badges/8acbf50474596bc201ab/maintainability)](https://codeclimate.com/github/SEIAROTg/autobean-refactor/maintainability)
[![license](https://img.shields.io/github/license/SEIAROTg/autobean-refactor.svg)](https://github.com/SEIAROTg/autobean-refactor)

An ergonomic and lossless beancount manipulation library.
